/* GXmlListChildren.c generated by valac 0.34.6, the Vala compiler
 * generated from GXmlListChildren.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 0; tab-width: 2 -*- */
/* GXmlListChildren.vala
 *
 * Copyright (C) 2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libxml/tree.h>


#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GLIST_CHILDREN (gxml_glist_children_get_type ())
#define GXML_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildren))
#define GXML_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))
#define GXML_IS_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_CHILDREN))
#define GXML_IS_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_CHILDREN))
#define GXML_GLIST_CHILDREN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))

typedef struct _GXmlGListChildren GXmlGListChildren;
typedef struct _GXmlGListChildrenClass GXmlGListChildrenClass;
typedef struct _GXmlGListChildrenPrivate GXmlGListChildrenPrivate;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_GLIST_CHILDREN_TYPE_ITERATOR (gxml_glist_children_iterator_get_type ())
#define GXML_GLIST_CHILDREN_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIterator))
#define GXML_GLIST_CHILDREN_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIteratorClass))
#define GXML_GLIST_CHILDREN_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GLIST_CHILDREN_TYPE_ITERATOR))
#define GXML_GLIST_CHILDREN_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GLIST_CHILDREN_TYPE_ITERATOR))
#define GXML_GLIST_CHILDREN_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIteratorClass))

typedef struct _GXmlGListChildrenIterator GXmlGListChildrenIterator;
typedef struct _GXmlGListChildrenIteratorClass GXmlGListChildrenIteratorClass;

#define GXML_TYPE_GNAMESPACE (gxml_gnamespace_get_type ())
#define GXML_GNAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNAMESPACE, GXmlGNamespace))
#define GXML_GNAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNAMESPACE, GXmlGNamespaceClass))
#define GXML_IS_GNAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNAMESPACE))
#define GXML_IS_GNAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNAMESPACE))
#define GXML_GNAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNAMESPACE, GXmlGNamespaceClass))

typedef struct _GXmlGNamespace GXmlGNamespace;
typedef struct _GXmlGNamespaceClass GXmlGNamespaceClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _GXmlGListChildrenIteratorPrivate GXmlGListChildrenIteratorPrivate;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlGListChildren {
	GeeAbstractBidirList parent_instance;
	GXmlGListChildrenPrivate * priv;
};

struct _GXmlGListChildrenClass {
	GeeAbstractBidirListClass parent_class;
};

struct _GXmlGListChildrenPrivate {
	GXmlGDocument* _doc;
	xmlNode* _node;
};

struct _GXmlGListChildrenIterator {
	GObject parent_instance;
	GXmlGListChildrenIteratorPrivate * priv;
};

struct _GXmlGListChildrenIteratorClass {
	GObjectClass parent_class;
};

struct _GXmlGListChildrenIteratorPrivate {
	GXmlGDocument* _doc;
	xmlNode* _node;
	xmlNode* _current;
	gint i;
};


static gpointer gxml_glist_children_parent_class = NULL;
static gpointer gxml_glist_children_iterator_parent_class = NULL;
static GeeTraversableIface* gxml_glist_children_iterator_gee_traversable_parent_iface = NULL;
static GeeIteratorIface* gxml_glist_children_iterator_gee_iterator_parent_iface = NULL;
static GeeBidirIteratorIface* gxml_glist_children_iterator_gee_bidir_iterator_parent_iface = NULL;
static GeeListIteratorIface* gxml_glist_children_iterator_gee_list_iterator_parent_iface = NULL;
static GeeBidirListIteratorIface* gxml_glist_children_iterator_gee_bidir_list_iterator_parent_iface = NULL;
static GXmlDomNodeListIface* gxml_glist_children_gxml_dom_node_list_parent_iface = NULL;
static GXmlDomHTMLCollectionIface* gxml_glist_children_gxml_dom_html_collection_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_glist_children_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
#define GXML_GLIST_CHILDREN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenPrivate))
enum  {
	GXML_GLIST_CHILDREN_DUMMY_PROPERTY,
	GXML_GLIST_CHILDREN_SIZE,
	GXML_GLIST_CHILDREN_READ_ONLY,
	GXML_GLIST_CHILDREN_LENGTH
};
GXmlGListChildren* gxml_glist_children_new (GXmlGDocument* doc, xmlNode* node);
GXmlGListChildren* gxml_glist_children_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
static GeeBidirListIterator* gxml_glist_children_real_bidir_list_iterator (GeeAbstractBidirList* base);
GXmlGListChildrenIterator* gxml_glist_children_iterator_new (GXmlGDocument* doc, xmlNode* node);
GXmlGListChildrenIterator* gxml_glist_children_iterator_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_glist_children_iterator_get_type (void) G_GNUC_CONST;
static GXmlNode* gxml_glist_children_real_get (GeeAbstractList* base, gint index);
GXmlNode* gxml_gnode_to_gnode (GXmlGDocument* doc, xmlNode* node);
static gint gxml_glist_children_real_index_of (GeeAbstractList* base, GXmlNode* item);
xmlNode* gxml_gnode_get_internal_node (GXmlGNode* self);
static void gxml_glist_children_real_insert (GeeAbstractList* base, gint index, GXmlNode* item);
static GeeListIterator* gxml_glist_children_real_list_iterator (GeeAbstractList* base);
static GXmlNode* gxml_glist_children_real_remove_at (GeeAbstractList* base, gint index);
static void gxml_glist_children_real_set (GeeAbstractList* base, gint index, GXmlNode* item);
static GeeList* gxml_glist_children_real_slice (GeeAbstractList* base, gint start, gint stop);
static gboolean gxml_glist_children_real_add (GeeAbstractCollection* base, GXmlNode* item);
GType gxml_gnamespace_get_type (void) G_GNUC_CONST;
gchar* gxml_namespace_get_uri (GXmlNamespace* self);
gchar* gxml_namespace_get_prefix (GXmlNamespace* self);
static void gxml_glist_children_real_clear (GeeAbstractCollection* base);
static gboolean gxml_glist_children_real_contains (GeeAbstractCollection* base, GXmlNode* item);
static GeeIterator* gxml_glist_children_real_iterator (GeeAbstractCollection* base);
static gboolean gxml_glist_children_real_remove (GeeAbstractCollection* base, GXmlNode* item);
static GXmlDomNode* gxml_glist_children_real_item (GXmlDomNodeList* base, gint index);
static GXmlDomElement* gxml_glist_children_real_get_element (GXmlDomHTMLCollection* base, gint index);
#define GXML_GLIST_CHILDREN_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIteratorPrivate))
enum  {
	GXML_GLIST_CHILDREN_ITERATOR_DUMMY_PROPERTY,
	GXML_GLIST_CHILDREN_ITERATOR_READ_ONLY,
	GXML_GLIST_CHILDREN_ITERATOR_VALID
};
static void gxml_glist_children_iterator_real_insert (GeeBidirListIterator* base, GXmlNode* item);
static void gxml_glist_children_iterator_real_add (GeeListIterator* base, GXmlNode* item);
static gint gxml_glist_children_iterator_real_index (GeeListIterator* base);
static void gxml_glist_children_iterator_real_set (GeeListIterator* base, GXmlNode* item);
static GXmlNode* gxml_glist_children_iterator_real_get (GeeIterator* base);
static gboolean gxml_glist_children_iterator_real_has_next (GeeIterator* base);
static gboolean gxml_glist_children_iterator_real_next (GeeIterator* base);
static void gxml_glist_children_iterator_real_remove (GeeIterator* base);
static gboolean gxml_glist_children_iterator_real_foreach (GeeTraversable* base, GeeForallFunc f, void* f_target);
static gboolean gxml_glist_children_iterator_real_first (GeeBidirIterator* base);
static gboolean gxml_glist_children_iterator_real_has_previous (GeeBidirIterator* base);
static gboolean gxml_glist_children_iterator_real_last (GeeBidirIterator* base);
static gboolean gxml_glist_children_iterator_real_previous (GeeBidirIterator* base);
static void gxml_glist_children_iterator_finalize (GObject* obj);
static void _vala_gxml_glist_children_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void gxml_glist_children_finalize (GObject* obj);
gint gxml_dom_node_list_get_length (GXmlDomNodeList* self);
static void _vala_gxml_glist_children_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


GXmlGListChildren* gxml_glist_children_construct (GType object_type, GXmlGDocument* doc, xmlNode* node) {
	GXmlGListChildren * self = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlGDocument* _tmp1_ = NULL;
	GXmlGDocument* _tmp2_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGListChildren*) gee_abstract_bidir_list_construct (object_type, GXML_TYPE_NODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
	_tmp0_ = node;
	self->priv->_node = _tmp0_;
	_tmp1_ = doc;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp2_;
	return self;
}


GXmlGListChildren* gxml_glist_children_new (GXmlGDocument* doc, xmlNode* node) {
	return gxml_glist_children_construct (GXML_TYPE_GLIST_CHILDREN, doc, node);
}


static GeeBidirListIterator* gxml_glist_children_real_bidir_list_iterator (GeeAbstractBidirList* base) {
	GXmlGListChildren * self;
	GeeBidirListIterator* result = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGListChildrenIterator* _tmp2_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_glist_children_iterator_new (_tmp0_, _tmp1_);
	result = (GeeBidirListIterator*) _tmp2_;
	return result;
}


static GXmlNode* gxml_glist_children_real_get (GeeAbstractList* base, gint index) {
	GXmlGListChildren * self;
	GXmlNode* result = NULL;
	GXmlNode* nullnode = NULL;
	xmlNode* _tmp0_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	gint i = 0;
	self = (GXmlGListChildren*) base;
	nullnode = NULL;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = nullnode;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	n = _tmp2_;
	i = 0;
	while (TRUE) {
		xmlNode* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _tmp9_ = 0;
		xmlNode* _tmp10_ = NULL;
		xmlNode* _tmp11_ = NULL;
		_tmp3_ = n;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = i;
		_tmp5_ = index;
		if (_tmp4_ == _tmp5_) {
			GXmlGDocument* _tmp6_ = NULL;
			xmlNode* _tmp7_ = NULL;
			GXmlNode* _tmp8_ = NULL;
			_tmp6_ = self->priv->_doc;
			_tmp7_ = n;
			_tmp8_ = gxml_gnode_to_gnode (_tmp6_, _tmp7_);
			result = _tmp8_;
			_g_object_unref0 (nullnode);
			return result;
		}
		_tmp9_ = i;
		i = _tmp9_ + 1;
		_tmp10_ = n;
		_tmp11_ = _tmp10_->next;
		n = _tmp11_;
	}
	result = nullnode;
	return result;
}


static gint gxml_glist_children_real_index_of (GeeAbstractList* base, GXmlNode* item) {
	GXmlGListChildren * self;
	gint result = 0;
	xmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	gint i = 0;
	self = (GXmlGListChildren*) base;
	g_return_val_if_fail (item != NULL, 0);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = -1;
		return result;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GNODE)) {
		result = -1;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->children;
	n = _tmp3_;
	i = 0;
	while (TRUE) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		xmlNode* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		_tmp4_ = n;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = n;
		_tmp6_ = item;
		_tmp7_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GXML_TYPE_GNODE, GXmlGNode));
		if (_tmp5_ == _tmp7_) {
			result = i;
			return result;
		}
		_tmp8_ = n;
		_tmp9_ = _tmp8_->next;
		n = _tmp9_;
		_tmp10_ = i;
		i = _tmp10_ + 1;
	}
	result = -1;
	return result;
}


/**
   * Insert @item before @index
   */
static void gxml_glist_children_real_insert (GeeAbstractList* base, gint index, GXmlNode* item) {
	GXmlGListChildren * self;
	GXmlNode* n = NULL;
	gint _tmp0_ = 0;
	gpointer _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	GXmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	xmlNode* _tmp6_ = NULL;
	self = (GXmlGListChildren*) base;
	g_return_if_fail (item != NULL);
	_tmp0_ = index;
	_tmp1_ = gee_abstract_list_get ((GeeAbstractList*) self, _tmp0_);
	n = (GXmlNode*) _tmp1_;
	_tmp2_ = n;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (n);
		return;
	}
	_tmp3_ = n;
	_tmp4_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp3_) : NULL);
	_tmp5_ = item;
	_tmp6_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp5_) : NULL);
	xmlAddPrevSibling (_tmp4_, _tmp6_);
	_g_object_unref0 (n);
}


static GeeListIterator* gxml_glist_children_real_list_iterator (GeeAbstractList* base) {
	GXmlGListChildren * self;
	GeeListIterator* result = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGListChildrenIterator* _tmp2_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_glist_children_iterator_new (_tmp0_, _tmp1_);
	result = (GeeListIterator*) _tmp2_;
	return result;
}


/**
   * Removes a node at @index. This method never returns a valid pointer.
   */
static GXmlNode* gxml_glist_children_real_remove_at (GeeAbstractList* base, gint index) {
	GXmlGListChildren * self;
	GXmlNode* result = NULL;
	GXmlNode* nullnode = NULL;
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GXmlNode* n = NULL;
	gint _tmp5_ = 0;
	gpointer _tmp6_ = NULL;
	GXmlNode* _tmp7_ = NULL;
	xmlNode* np = NULL;
	GXmlNode* _tmp8_ = NULL;
	xmlNode* _tmp9_ = NULL;
	xmlNode* _tmp10_ = NULL;
	xmlNode* _tmp11_ = NULL;
	self = (GXmlGListChildren*) base;
	nullnode = NULL;
	_tmp1_ = index;
	_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) self);
	_tmp3_ = _tmp2_;
	if (_tmp1_ > _tmp3_) {
		_tmp0_ = TRUE;
	} else {
		gint _tmp4_ = 0;
		_tmp4_ = index;
		_tmp0_ = _tmp4_ < 0;
	}
	if (_tmp0_) {
		result = nullnode;
		return result;
	}
	_tmp5_ = index;
	_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) self, _tmp5_);
	n = (GXmlNode*) _tmp6_;
	_tmp7_ = n;
	if (_tmp7_ == NULL) {
		result = nullnode;
		_g_object_unref0 (n);
		return result;
	}
	_tmp8_ = n;
	_tmp9_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GXML_TYPE_GNODE) ? ((GXmlGNode*) _tmp8_) : NULL);
	np = _tmp9_;
	_tmp10_ = np;
	xmlUnlinkNode (_tmp10_);
	_tmp11_ = np;
	xmlFreeNode (_tmp11_);
	result = nullnode;
	_g_object_unref0 (n);
	return result;
}


/**
   * This method is ignored by default.
   */
static void gxml_glist_children_real_set (GeeAbstractList* base, gint index, GXmlNode* item) {
	GXmlGListChildren * self;
	self = (GXmlGListChildren*) base;
	g_return_if_fail (item != NULL);
}


static GeeList* gxml_glist_children_real_slice (GeeAbstractList* base, gint start, gint stop) {
	GXmlGListChildren * self;
	GeeList* result = NULL;
	GeeArrayList* l = NULL;
	GeeArrayList* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	gint i = 0;
	self = (GXmlGListChildren*) base;
	_tmp0_ = gee_array_list_new (GXML_TYPE_NODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	l = _tmp0_;
	_tmp1_ = self->priv->_node;
	if (_tmp1_ == NULL) {
		result = (GeeList*) l;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->children;
	n = _tmp3_;
	i = 0;
	while (TRUE) {
		xmlNode* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		xmlNode* _tmp15_ = NULL;
		xmlNode* _tmp16_ = NULL;
		gint _tmp17_ = 0;
		_tmp4_ = n;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp6_ = i;
		_tmp7_ = start;
		if (_tmp6_ >= _tmp7_) {
			gint _tmp8_ = 0;
			gint _tmp9_ = 0;
			_tmp8_ = i;
			_tmp9_ = stop;
			_tmp5_ = _tmp8_ <= _tmp9_;
		} else {
			_tmp5_ = FALSE;
		}
		if (_tmp5_) {
			GeeArrayList* _tmp10_ = NULL;
			GXmlGDocument* _tmp11_ = NULL;
			xmlNode* _tmp12_ = NULL;
			GXmlNode* _tmp13_ = NULL;
			GXmlNode* _tmp14_ = NULL;
			_tmp10_ = l;
			_tmp11_ = self->priv->_doc;
			_tmp12_ = n;
			_tmp13_ = gxml_gnode_to_gnode (_tmp11_, _tmp12_);
			_tmp14_ = _tmp13_;
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp10_, _tmp14_);
			_g_object_unref0 (_tmp14_);
		}
		_tmp15_ = n;
		_tmp16_ = _tmp15_->next;
		n = _tmp16_;
		_tmp17_ = i;
		i = _tmp17_ + 1;
	}
	result = (GeeList*) l;
	return result;
}


static gboolean gxml_glist_children_real_add (GeeAbstractCollection* base, GXmlNode* item) {
	GXmlGListChildren * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GXmlNamespace* ns = NULL;
	GXmlNode* _tmp6_ = NULL;
	GXmlNamespace* _tmp7_ = NULL;
	xmlNode* _tmp8_ = NULL;
	GXmlNamespace* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	GXmlNamespace* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	xmlNs* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	self = (GXmlGListChildren*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GNAMESPACE)) {
		xmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		_tmp2_ = self->priv->_node;
		_tmp3_ = item;
		_tmp4_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_GNODE, GXmlGNode));
		_tmp5_ = xmlAddChild (_tmp2_, _tmp4_);
		result = _tmp5_ != NULL;
		return result;
	}
	_tmp6_ = item;
	_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GXML_TYPE_NAMESPACE, GXmlNamespace));
	ns = _tmp7_;
	_tmp8_ = self->priv->_node;
	_tmp9_ = ns;
	_tmp10_ = gxml_namespace_get_uri (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp13_ = ns;
	_tmp14_ = gxml_namespace_get_prefix (_tmp13_);
	_tmp15_ = _tmp14_;
	_tmp16_ = _tmp15_;
	_tmp17_ = xmlNewNs (_tmp8_, (xmlChar*) _tmp12_, (xmlChar*) _tmp16_);
	_tmp18_ = _tmp17_ != NULL;
	_g_free0 (_tmp16_);
	_g_free0 (_tmp12_);
	result = _tmp18_;
	_g_object_unref0 (ns);
	return result;
}


static void gxml_glist_children_real_clear (GeeAbstractCollection* base) {
	GXmlGListChildren * self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	xmlFreeNodeList (_tmp2_);
}


static gboolean gxml_glist_children_real_contains (GeeAbstractCollection* base, GXmlNode* item) {
	GXmlGListChildren * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	self = (GXmlGListChildren*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GNODE)) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->children;
	n = _tmp3_;
	while (TRUE) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		xmlNode* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		_tmp4_ = n;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = n;
		_tmp6_ = item;
		_tmp7_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GXML_TYPE_GNODE, GXmlGNode));
		if (_tmp5_ == _tmp7_) {
			result = TRUE;
			return result;
		}
		_tmp8_ = n;
		_tmp9_ = _tmp8_->next;
		n = _tmp9_;
	}
	result = FALSE;
	return result;
}


static GeeIterator* gxml_glist_children_real_iterator (GeeAbstractCollection* base) {
	GXmlGListChildren * self;
	GeeIterator* result = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGListChildrenIterator* _tmp2_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_glist_children_iterator_new (_tmp0_, _tmp1_);
	result = (GeeIterator*) _tmp2_;
	return result;
}


static gboolean gxml_glist_children_real_remove (GeeAbstractCollection* base, GXmlNode* item) {
	GXmlGListChildren * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	self = (GXmlGListChildren*) base;
	g_return_val_if_fail (item != NULL, FALSE);
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = item;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GNODE)) {
		result = FALSE;
		return result;
	}
	_tmp2_ = self->priv->_node;
	_tmp3_ = _tmp2_->children;
	n = _tmp3_;
	while (TRUE) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		xmlNode* _tmp10_ = NULL;
		xmlNode* _tmp11_ = NULL;
		_tmp4_ = n;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = n;
		_tmp6_ = item;
		_tmp7_ = gxml_gnode_get_internal_node (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GXML_TYPE_GNODE, GXmlGNode));
		if (_tmp5_ == _tmp7_) {
			xmlNode* _tmp8_ = NULL;
			xmlNode* _tmp9_ = NULL;
			_tmp8_ = n;
			xmlUnlinkNode (_tmp8_);
			_tmp9_ = n;
			xmlFreeNode (_tmp9_);
			result = TRUE;
			return result;
		}
		_tmp10_ = n;
		_tmp11_ = _tmp10_->next;
		n = _tmp11_;
	}
	result = FALSE;
	return result;
}


static GXmlDomNode* gxml_glist_children_real_item (GXmlDomNodeList* base, gint index) {
	GXmlGListChildren * self;
	GXmlDomNode* result = NULL;
	gint _tmp0_ = 0;
	gpointer _tmp1_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp0_ = index;
	_tmp1_ = gee_abstract_list_get ((GeeAbstractList*) self, _tmp0_);
	result = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp1_, GXML_TYPE_DOM_NODE, GXmlDomNode);
	return result;
}


static GXmlDomElement* gxml_glist_children_real_get_element (GXmlDomHTMLCollection* base, gint index) {
	GXmlGListChildren * self;
	GXmlDomElement* result = NULL;
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GXmlNode* e = NULL;
	gint _tmp5_ = 0;
	gpointer _tmp6_ = NULL;
	GXmlNode* _tmp7_ = NULL;
	GXmlNode* _tmp8_ = NULL;
	GXmlDomElement* _tmp9_ = NULL;
	self = (GXmlGListChildren*) base;
	_tmp1_ = index;
	_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) self);
	_tmp3_ = _tmp2_;
	if (_tmp1_ > _tmp3_) {
		_tmp0_ = TRUE;
	} else {
		gint _tmp4_ = 0;
		_tmp4_ = index;
		_tmp0_ = _tmp4_ < 0;
	}
	if (_tmp0_) {
		result = NULL;
		return result;
	}
	_tmp5_ = index;
	_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) self, _tmp5_);
	e = (GXmlNode*) _tmp6_;
	_tmp7_ = e;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_NODE)) {
		result = NULL;
		_g_object_unref0 (e);
		return result;
	}
	_tmp8_ = e;
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
	result = _tmp9_;
	_g_object_unref0 (e);
	return result;
}


static gint gxml_glist_children_real_get_size (GeeAbstractCollection* base) {
	gint result;
	GXmlGListChildren* self;
	xmlNode* _tmp0_ = NULL;
	gint i = 0;
	xmlNode* n = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	gint _tmp7_ = 0;
	self = (GXmlGListChildren*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = -1;
		return result;
	}
	i = 0;
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	n = _tmp2_;
	while (TRUE) {
		xmlNode* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		xmlNode* _tmp5_ = NULL;
		xmlNode* _tmp6_ = NULL;
		_tmp3_ = n;
		if (!(_tmp3_ != NULL)) {
			break;
		}
		_tmp4_ = i;
		i = _tmp4_ + 1;
		_tmp5_ = n;
		_tmp6_ = _tmp5_->next;
		n = _tmp6_;
	}
	_tmp7_ = i;
	result = _tmp7_;
	return result;
}


static gboolean gxml_glist_children_real_get_read_only (GeeAbstractCollection* base) {
	gboolean result;
	GXmlGListChildren* self;
	self = (GXmlGListChildren*) base;
	result = FALSE;
	return result;
}


static gint gxml_glist_children_real_get_length (GXmlDomNodeList* base) {
	gint result;
	GXmlGListChildren* self;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	self = (GXmlGListChildren*) base;
	_tmp0_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


GXmlGListChildrenIterator* gxml_glist_children_iterator_construct (GType object_type, GXmlGDocument* doc, xmlNode* node) {
	GXmlGListChildrenIterator * self = NULL;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	GXmlGDocument* _tmp3_ = NULL;
	GXmlGDocument* _tmp4_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGListChildrenIterator*) g_object_new (object_type, NULL);
	_tmp0_ = node;
	self->priv->_node = _tmp0_;
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	self->priv->_current = _tmp2_;
	_tmp3_ = doc;
	_tmp4_ = _g_object_ref0 (_tmp3_);
	_g_object_unref0 (self->priv->_doc);
	self->priv->_doc = _tmp4_;
	return self;
}


GXmlGListChildrenIterator* gxml_glist_children_iterator_new (GXmlGDocument* doc, xmlNode* node) {
	return gxml_glist_children_iterator_construct (GXML_GLIST_CHILDREN_TYPE_ITERATOR, doc, node);
}


/**
     * This method is ignored by default.
     */
static void gxml_glist_children_iterator_real_insert (GeeBidirListIterator* base, GXmlNode* item) {
	GXmlGListChildrenIterator * self;
	self = (GXmlGListChildrenIterator*) base;
	g_return_if_fail (item != NULL);
}


/**
     * This method is ignored by default.
     */
static void gxml_glist_children_iterator_real_add (GeeListIterator* base, GXmlNode* item) {
	GXmlGListChildrenIterator * self;
	self = (GXmlGListChildrenIterator*) base;
	g_return_if_fail (item != NULL);
}


static gint gxml_glist_children_iterator_real_index (GeeListIterator* base) {
	GXmlGListChildrenIterator * self;
	gint result = 0;
	gint _tmp0_ = 0;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->i;
	result = _tmp0_;
	return result;
}


/**
     * This method is ignored by default.
     */
static void gxml_glist_children_iterator_real_set (GeeListIterator* base, GXmlNode* item) {
	GXmlGListChildrenIterator * self;
	self = (GXmlGListChildrenIterator*) base;
	g_return_if_fail (item != NULL);
}


static GXmlNode* gxml_glist_children_iterator_real_get (GeeIterator* base) {
	GXmlGListChildrenIterator * self;
	GXmlNode* result = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_doc;
	_tmp1_ = self->priv->_node;
	_tmp2_ = gxml_gnode_to_gnode (_tmp0_, _tmp1_);
	result = _tmp2_;
	return result;
}


static gboolean gxml_glist_children_iterator_real_has_next (GeeIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp6_ = NULL;
	xmlNode* _tmp7_ = NULL;
	xmlNode* _tmp8_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_current;
	if (_tmp3_ != NULL) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		_tmp4_ = self->priv->_current;
		_tmp5_ = _tmp4_->next;
		if (_tmp5_ != NULL) {
			result = TRUE;
			return result;
		}
	}
	_tmp6_ = self->priv->_node;
	_tmp7_ = _tmp6_->children;
	_tmp8_ = _tmp7_->next;
	result = _tmp8_ != NULL;
	return result;
}


static gboolean gxml_glist_children_iterator_real_next (GeeIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp6_ = NULL;
	xmlNode* _tmp7_ = NULL;
	xmlNode* _tmp8_ = NULL;
	xmlNode* _tmp9_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = gee_iterator_has_next ((GeeIterator*) self);
	if (!_tmp0_) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_current;
	if (_tmp3_ == NULL) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		_tmp4_ = self->priv->_node;
		_tmp5_ = _tmp4_->children;
		self->priv->_current = _tmp5_;
	}
	_tmp6_ = self->priv->_current;
	_tmp7_ = _tmp6_->next;
	if (_tmp7_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp8_ = self->priv->_current;
	_tmp9_ = _tmp8_->next;
	self->priv->_current = _tmp9_;
	result = TRUE;
	return result;
}


static void gxml_glist_children_iterator_real_remove (GeeIterator* base) {
	GXmlGListChildrenIterator * self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* n = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	xmlNode* _tmp5_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_current;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->priv->_current;
	n = _tmp1_;
	_tmp2_ = self->priv->_current;
	_tmp3_ = _tmp2_->prev;
	self->priv->_current = _tmp3_;
	_tmp4_ = n;
	xmlUnlinkNode (_tmp4_);
	_tmp5_ = n;
	xmlFreeNode (_tmp5_);
}


static gboolean gxml_glist_children_iterator_real_foreach (GeeTraversable* base, GeeForallFunc f, void* f_target) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	self = (GXmlGListChildrenIterator*) base;
	while (TRUE) {
		gboolean _tmp0_ = FALSE;
		GeeForallFunc _tmp1_ = NULL;
		void* _tmp1__target = NULL;
		gpointer _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		_tmp0_ = gee_iterator_has_next ((GeeIterator*) self);
		if (!_tmp0_) {
			break;
		}
		gee_iterator_next ((GeeIterator*) self);
		_tmp1_ = f;
		_tmp1__target = f_target;
		_tmp2_ = gee_iterator_get ((GeeIterator*) self);
		_tmp3_ = _tmp1_ ((GXmlNode*) _tmp2_, _tmp1__target);
		if (!_tmp3_) {
			result = FALSE;
			return result;
		}
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_children_iterator_real_first (GeeBidirIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	xmlNode* _tmp5_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_node;
	_tmp4_ = _tmp3_->children;
	self->priv->_current = _tmp4_;
	_tmp5_ = self->priv->_current;
	result = _tmp5_ != NULL;
	return result;
}


static gboolean gxml_glist_children_iterator_real_has_previous (GeeBidirIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	xmlNode* _tmp5_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_current;
	if (_tmp3_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp4_ = self->priv->_current;
	_tmp5_ = _tmp4_->prev;
	if (_tmp5_ == NULL) {
		result = FALSE;
		return result;
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_children_iterator_real_last (GeeBidirIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_node;
	_tmp4_ = _tmp3_->children;
	self->priv->_current = _tmp4_;
	while (TRUE) {
		xmlNode* _tmp5_ = NULL;
		xmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		xmlNode* _tmp8_ = NULL;
		_tmp5_ = self->priv->_current;
		_tmp6_ = _tmp5_->next;
		if (!(_tmp6_ != NULL)) {
			break;
		}
		_tmp7_ = self->priv->_current;
		_tmp8_ = _tmp7_->next;
		self->priv->_current = _tmp8_;
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_children_iterator_real_previous (GeeBidirIterator* base) {
	GXmlGListChildrenIterator * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->priv->_node;
	_tmp2_ = _tmp1_->children;
	if (_tmp2_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp3_ = self->priv->_current;
	if (_tmp3_ == NULL) {
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
		_tmp4_ = self->priv->_node;
		_tmp5_ = _tmp4_->children;
		self->priv->_current = _tmp5_;
		result = TRUE;
		return result;
	}
	while (TRUE) {
		xmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		xmlNode* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		_tmp6_ = self->priv->_current;
		_tmp7_ = _tmp6_->prev;
		if (!(_tmp7_ != NULL)) {
			break;
		}
		_tmp8_ = self->priv->_current;
		_tmp9_ = _tmp8_->prev;
		self->priv->_current = _tmp9_;
	}
	result = TRUE;
	return result;
}


static gboolean gxml_glist_children_iterator_real_get_read_only (GeeIterator* base) {
	gboolean result;
	GXmlGListChildrenIterator* self;
	self = (GXmlGListChildrenIterator*) base;
	result = FALSE;
	return result;
}


static gboolean gxml_glist_children_iterator_real_get_valid (GeeIterator* base) {
	gboolean result;
	GXmlGListChildrenIterator* self;
	xmlNode* _tmp0_ = NULL;
	self = (GXmlGListChildrenIterator*) base;
	_tmp0_ = self->priv->_current;
	result = _tmp0_ != NULL;
	return result;
}


static void gxml_glist_children_iterator_class_init (GXmlGListChildrenIteratorClass * klass) {
	gxml_glist_children_iterator_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGListChildrenIteratorPrivate));
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_glist_children_iterator_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_glist_children_iterator_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_CHILDREN_ITERATOR_READ_ONLY, g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_CHILDREN_ITERATOR_VALID, g_param_spec_boolean ("valid", "valid", "valid", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static GType gxml_glist_children_iterator_gee_traversable_get_g_type (GXmlGListChildrenIterator* self) {
	return GXML_TYPE_NODE;
}


static GBoxedCopyFunc gxml_glist_children_iterator_gee_traversable_get_g_dup_func (GXmlGListChildrenIterator* self) {
	return g_object_ref;
}


static GDestroyNotify gxml_glist_children_iterator_gee_traversable_get_g_destroy_func (GXmlGListChildrenIterator* self) {
	return g_object_unref;
}


static void gxml_glist_children_iterator_gee_traversable_interface_init (GeeTraversableIface * iface) {
	gxml_glist_children_iterator_gee_traversable_parent_iface = g_type_interface_peek_parent (iface);
	iface->foreach = (gboolean (*)(GeeTraversable*, GeeForallFunc, void*)) gxml_glist_children_iterator_real_foreach;
	iface->get_g_type = (GType(*)(GeeTraversable*)) gxml_glist_children_iterator_gee_traversable_get_g_type;
	iface->get_g_dup_func = (GBoxedCopyFunc(*)(GeeTraversable*)) gxml_glist_children_iterator_gee_traversable_get_g_dup_func;
	iface->get_g_destroy_func = (GDestroyNotify(*)(GeeTraversable*)) gxml_glist_children_iterator_gee_traversable_get_g_destroy_func;
}


static void gxml_glist_children_iterator_gee_iterator_interface_init (GeeIteratorIface * iface) {
	gxml_glist_children_iterator_gee_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->get = (gpointer (*)(GeeIterator*)) gxml_glist_children_iterator_real_get;
	iface->has_next = (gboolean (*)(GeeIterator*)) gxml_glist_children_iterator_real_has_next;
	iface->next = (gboolean (*)(GeeIterator*)) gxml_glist_children_iterator_real_next;
	iface->remove = (void (*)(GeeIterator*)) gxml_glist_children_iterator_real_remove;
	iface->get_read_only = gxml_glist_children_iterator_real_get_read_only;
	iface->get_valid = gxml_glist_children_iterator_real_get_valid;
}


static GType gxml_glist_children_iterator_gee_bidir_iterator_get_g_type (GXmlGListChildrenIterator* self) {
	return GXML_TYPE_NODE;
}


static GBoxedCopyFunc gxml_glist_children_iterator_gee_bidir_iterator_get_g_dup_func (GXmlGListChildrenIterator* self) {
	return g_object_ref;
}


static GDestroyNotify gxml_glist_children_iterator_gee_bidir_iterator_get_g_destroy_func (GXmlGListChildrenIterator* self) {
	return g_object_unref;
}


static void gxml_glist_children_iterator_gee_bidir_iterator_interface_init (GeeBidirIteratorIface * iface) {
	gxml_glist_children_iterator_gee_bidir_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->first = (gboolean (*)(GeeBidirIterator*)) gxml_glist_children_iterator_real_first;
	iface->has_previous = (gboolean (*)(GeeBidirIterator*)) gxml_glist_children_iterator_real_has_previous;
	iface->last = (gboolean (*)(GeeBidirIterator*)) gxml_glist_children_iterator_real_last;
	iface->previous = (gboolean (*)(GeeBidirIterator*)) gxml_glist_children_iterator_real_previous;
	iface->get_g_type = (GType(*)(GeeBidirIterator*)) gxml_glist_children_iterator_gee_bidir_iterator_get_g_type;
	iface->get_g_dup_func = (GBoxedCopyFunc(*)(GeeBidirIterator*)) gxml_glist_children_iterator_gee_bidir_iterator_get_g_dup_func;
	iface->get_g_destroy_func = (GDestroyNotify(*)(GeeBidirIterator*)) gxml_glist_children_iterator_gee_bidir_iterator_get_g_destroy_func;
}


static void gxml_glist_children_iterator_gee_list_iterator_interface_init (GeeListIteratorIface * iface) {
	gxml_glist_children_iterator_gee_list_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->add = (void (*)(GeeListIterator*, gconstpointer)) gxml_glist_children_iterator_real_add;
	iface->index = (gint (*)(GeeListIterator*)) gxml_glist_children_iterator_real_index;
	iface->set = (void (*)(GeeListIterator*, gconstpointer)) gxml_glist_children_iterator_real_set;
}


static GType gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_type (GXmlGListChildrenIterator* self) {
	return GXML_TYPE_NODE;
}


static GBoxedCopyFunc gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_dup_func (GXmlGListChildrenIterator* self) {
	return g_object_ref;
}


static GDestroyNotify gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_destroy_func (GXmlGListChildrenIterator* self) {
	return g_object_unref;
}


static void gxml_glist_children_iterator_gee_bidir_list_iterator_interface_init (GeeBidirListIteratorIface * iface) {
	gxml_glist_children_iterator_gee_bidir_list_iterator_parent_iface = g_type_interface_peek_parent (iface);
	iface->insert = (void (*)(GeeBidirListIterator*, gconstpointer)) gxml_glist_children_iterator_real_insert;
	iface->get_g_type = (GType(*)(GeeBidirListIterator*)) gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_type;
	iface->get_g_dup_func = (GBoxedCopyFunc(*)(GeeBidirListIterator*)) gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_dup_func;
	iface->get_g_destroy_func = (GDestroyNotify(*)(GeeBidirListIterator*)) gxml_glist_children_iterator_gee_bidir_list_iterator_get_g_destroy_func;
}


static void gxml_glist_children_iterator_instance_init (GXmlGListChildrenIterator * self) {
	self->priv = GXML_GLIST_CHILDREN_ITERATOR_GET_PRIVATE (self);
	self->priv->i = 0;
}


static void gxml_glist_children_iterator_finalize (GObject* obj) {
	GXmlGListChildrenIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIterator);
	_g_object_unref0 (self->priv->_doc);
	G_OBJECT_CLASS (gxml_glist_children_iterator_parent_class)->finalize (obj);
}


GType gxml_glist_children_iterator_get_type (void) {
	static volatile gsize gxml_glist_children_iterator_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_glist_children_iterator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGListChildrenIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_glist_children_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGListChildrenIterator), 0, (GInstanceInitFunc) gxml_glist_children_iterator_instance_init, NULL };
		static const GInterfaceInfo gee_traversable_info = { (GInterfaceInitFunc) gxml_glist_children_iterator_gee_traversable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gxml_glist_children_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_bidir_iterator_info = { (GInterfaceInitFunc) gxml_glist_children_iterator_gee_bidir_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_list_iterator_info = { (GInterfaceInitFunc) gxml_glist_children_iterator_gee_list_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gee_bidir_list_iterator_info = { (GInterfaceInitFunc) gxml_glist_children_iterator_gee_bidir_list_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_glist_children_iterator_type_id;
		gxml_glist_children_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGListChildrenIterator", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_glist_children_iterator_type_id, GEE_TYPE_TRAVERSABLE, &gee_traversable_info);
		g_type_add_interface_static (gxml_glist_children_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
		g_type_add_interface_static (gxml_glist_children_iterator_type_id, GEE_TYPE_BIDIR_ITERATOR, &gee_bidir_iterator_info);
		g_type_add_interface_static (gxml_glist_children_iterator_type_id, GEE_TYPE_LIST_ITERATOR, &gee_list_iterator_info);
		g_type_add_interface_static (gxml_glist_children_iterator_type_id, GEE_TYPE_BIDIR_LIST_ITERATOR, &gee_bidir_list_iterator_info);
		g_once_init_leave (&gxml_glist_children_iterator_type_id__volatile, gxml_glist_children_iterator_type_id);
	}
	return gxml_glist_children_iterator_type_id__volatile;
}


static void _vala_gxml_glist_children_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGListChildrenIterator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GLIST_CHILDREN_TYPE_ITERATOR, GXmlGListChildrenIterator);
	switch (property_id) {
		case GXML_GLIST_CHILDREN_ITERATOR_READ_ONLY:
		g_value_set_boolean (value, gee_iterator_get_read_only ((GeeIterator*) self));
		break;
		case GXML_GLIST_CHILDREN_ITERATOR_VALID:
		g_value_set_boolean (value, gee_iterator_get_valid ((GeeIterator*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void gxml_glist_children_class_init (GXmlGListChildrenClass * klass) {
	gxml_glist_children_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGListChildrenPrivate));
	((GeeAbstractBidirListClass *) klass)->bidir_list_iterator = (GeeBidirListIterator* (*)(GeeAbstractBidirList*)) gxml_glist_children_real_bidir_list_iterator;
	((GeeAbstractListClass *) klass)->get = (gpointer (*)(GeeAbstractList*, gint)) gxml_glist_children_real_get;
	((GeeAbstractListClass *) klass)->index_of = (gint (*)(GeeAbstractList*, gconstpointer)) gxml_glist_children_real_index_of;
	((GeeAbstractListClass *) klass)->insert = (void (*)(GeeAbstractList*, gint, gconstpointer)) gxml_glist_children_real_insert;
	((GeeAbstractListClass *) klass)->list_iterator = (GeeListIterator* (*)(GeeAbstractList*)) gxml_glist_children_real_list_iterator;
	((GeeAbstractListClass *) klass)->remove_at = (gpointer (*)(GeeAbstractList*, gint)) gxml_glist_children_real_remove_at;
	((GeeAbstractListClass *) klass)->set = (void (*)(GeeAbstractList*, gint, gconstpointer)) gxml_glist_children_real_set;
	((GeeAbstractListClass *) klass)->slice = (GeeList* (*)(GeeAbstractList*, gint, gint)) gxml_glist_children_real_slice;
	((GeeAbstractCollectionClass *) klass)->add = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_children_real_add;
	((GeeAbstractCollectionClass *) klass)->clear = (void (*)(GeeAbstractCollection*)) gxml_glist_children_real_clear;
	((GeeAbstractCollectionClass *) klass)->contains = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_children_real_contains;
	((GeeAbstractCollectionClass *) klass)->iterator = (GeeIterator* (*)(GeeAbstractCollection*)) gxml_glist_children_real_iterator;
	((GeeAbstractCollectionClass *) klass)->remove = (gboolean (*)(GeeAbstractCollection*, gconstpointer)) gxml_glist_children_real_remove;
	GEE_ABSTRACT_COLLECTION_CLASS (klass)->get_size = gxml_glist_children_real_get_size;
	GEE_ABSTRACT_COLLECTION_CLASS (klass)->get_read_only = gxml_glist_children_real_get_read_only;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_glist_children_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_glist_children_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_CHILDREN_SIZE, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_CHILDREN_READ_ONLY, g_param_spec_boolean ("read-only", "read-only", "read-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GLIST_CHILDREN_LENGTH, g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_glist_children_gxml_dom_node_list_interface_init (GXmlDomNodeListIface * iface) {
	gxml_glist_children_gxml_dom_node_list_parent_iface = g_type_interface_peek_parent (iface);
	iface->item = (GXmlDomNode* (*)(GXmlDomNodeList*, gint)) gxml_glist_children_real_item;
	iface->get_length = gxml_glist_children_real_get_length;
}


static void gxml_glist_children_gxml_dom_html_collection_interface_init (GXmlDomHTMLCollectionIface * iface) {
	gxml_glist_children_gxml_dom_html_collection_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_element = (GXmlDomElement* (*)(GXmlDomHTMLCollection*, gint)) gxml_glist_children_real_get_element;
}


static void gxml_glist_children_instance_init (GXmlGListChildren * self) {
	self->priv = GXML_GLIST_CHILDREN_GET_PRIVATE (self);
}


static void gxml_glist_children_finalize (GObject* obj) {
	GXmlGListChildren * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GLIST_CHILDREN, GXmlGListChildren);
	_g_object_unref0 (self->priv->_doc);
	G_OBJECT_CLASS (gxml_glist_children_parent_class)->finalize (obj);
}


/**
 * A {@link Gee.AbstractBidirList} implementation to access {@link Xml.Node} collection
 */
GType gxml_glist_children_get_type (void) {
	static volatile gsize gxml_glist_children_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_glist_children_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGListChildrenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_glist_children_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGListChildren), 0, (GInstanceInitFunc) gxml_glist_children_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_node_list_info = { (GInterfaceInitFunc) gxml_glist_children_gxml_dom_node_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_html_collection_info = { (GInterfaceInitFunc) gxml_glist_children_gxml_dom_html_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_glist_children_type_id;
		gxml_glist_children_type_id = g_type_register_static (GEE_TYPE_ABSTRACT_BIDIR_LIST, "GXmlGListChildren", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_glist_children_type_id, GXML_TYPE_DOM_NODE_LIST, &gxml_dom_node_list_info);
		g_type_add_interface_static (gxml_glist_children_type_id, GXML_TYPE_DOM_HTML_COLLECTION, &gxml_dom_html_collection_info);
		g_once_init_leave (&gxml_glist_children_type_id__volatile, gxml_glist_children_type_id);
	}
	return gxml_glist_children_type_id__volatile;
}


static void _vala_gxml_glist_children_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGListChildren * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GLIST_CHILDREN, GXmlGListChildren);
	switch (property_id) {
		case GXML_GLIST_CHILDREN_SIZE:
		g_value_set_int (value, gee_abstract_collection_get_size ((GeeAbstractCollection*) self));
		break;
		case GXML_GLIST_CHILDREN_READ_ONLY:
		g_value_set_boolean (value, gee_abstract_collection_get_read_only ((GeeAbstractCollection*) self));
		break;
		case GXML_GLIST_CHILDREN_LENGTH:
		g_value_set_int (value, gxml_dom_node_list_get_length ((GXmlDomNodeList*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



